summaryrefslogtreecommitdiff
path: root/src/dev/intel_8254_timer.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/dev/intel_8254_timer.hh')
-rw-r--r--src/dev/intel_8254_timer.hh9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/dev/intel_8254_timer.hh b/src/dev/intel_8254_timer.hh
index bb650d33b..1bc2ab87b 100644
--- a/src/dev/intel_8254_timer.hh
+++ b/src/dev/intel_8254_timer.hh
@@ -98,6 +98,8 @@ class Intel8254Timer : public EventManager
friend class Counter;
void setTo(int clocks);
+
+ int clocksLeft();
};
private:
@@ -108,8 +110,8 @@ class Intel8254Timer : public EventManager
CounterEvent event;
- /** Current count value */
- uint16_t count;
+ /** Initial count value */
+ uint16_t initial_count;
/** Latched count */
uint16_t latched_count;
@@ -141,6 +143,9 @@ class Intel8254Timer : public EventManager
/** Latch the current count (if one is not already latched) */
void latchCount();
+ /** Get the current count for this counter */
+ int currentCount();
+
/** Set the read/write mode */
void setRW(int rw_val);